/*****************************************************************
**
**   MBox - A tool to interface Batch files with Windows 
**   MessageBoxs for user input and such.
**
**   By Anthony Anderberg
**   ant@anderbergfamily.net
**   4/1999
**
**   - Changed Email address: 12/2001
**
*****************************************************************/


#include <windows.h>
#include <stdio.h>

int main(int argc, char **argv)
{
  unsigned int buttontype, icontype;
  int returnvalue;
  
  if ((argc < 3)||(argc > 5))
   {
	   // Silly user didn't specify things right, show help.
	   printf("\n MBox v1.0    by Anthony Anderberg   (ant@anderbergfamily.net)\n");
	   printf("  Usage:\n   mbox.exe Button_Type Message_Text [Title_Bar_Text] [Icon]\n\n");
       	   printf("  Button Types:                   Button Return Values:\n");
	   printf("     OK     OK                          OK     1\n");
	   printf("     OKCAN  OK  Cancel                  Cancel 2\n");
	   printf("     YN     Yes No                      Abort  3\n");
	   printf("     YNC    Yes No Cancel               Retry  4\n");
	   printf("     RC     Retry Cancel                Ignor  5\n");
       	   printf("     ARI    Abort Retry Ignor           Yes    6\n");
	   printf("                                        No     7\n");
	   printf("  Icon Types:\n     WARN    Warning\n");
	   printf("     INFO    Information\n     QUEST   Question\n");
	   printf("     STOP    Stop Sign\n\n  Examples:\n");
       	   printf("     mbox.exe YN \"Continue with install?\" \"MyApp Installer\" QUEST\n");
	   printf("     mbox.exe OKCAN \"Copying completed, ready to continue.\" INFO\n");
	   printf("     mbox.exe OK \"Go Vikings!\"\n");
	   return 0;
   }

   if (!stricmp( argv[1], "OK"))
   {
	   buttontype = MB_OK;
   }
   else if ((!stricmp( argv[1], "OKCAN"))||(!stricmp( argv[1], "OC")))
   {
	   buttontype = MB_OKCANCEL;
   }
   else if ((!stricmp( argv[1], "YN"))||(!stricmp( argv[1], "YESNO")))
   {
	   buttontype = MB_YESNO;
   }
   else if ((!stricmp( argv[1], "YNC"))||(!stricmp( argv[1], "YESNOCAN")))
   {
	   buttontype = MB_YESNOCANCEL;
   }
   else if ((!stricmp( argv[1], "RC"))||(!stricmp( argv[1], "RETRYCANCEL")))
   {
	   buttontype = MB_RETRYCANCEL;
   }
   else if (!stricmp( argv[1], "ARI"))
   {
	   buttontype = MB_ABORTRETRYIGNORE;
   }
   else
   {
	   printf("MBox: Unknown button type.\n");
	   return 0;
   }


   if (argc == 3)
   {
      returnvalue = MessageBox(NULL,argv[2],"",buttontype);
   }
   else if (argc == 5)
   {
     if (!stricmp( argv[4], "WARN"))
	 {
	   icontype = MB_ICONWARNING;
	 }
     else if (!stricmp( argv[4], "INFO"))
	 { 
	   icontype = MB_ICONINFORMATION;
	 } 
     else if (!stricmp( argv[4], "QUEST"))
	 {
  	   icontype = MB_ICONQUESTION;
	 }  
     else if (!stricmp( argv[4], "STOP"))
	 { 
       icontype = MB_ICONSTOP;
	 } 
     else  // Nothing...
	 { 
	   icontype = 0;
	 } 
	 returnvalue = MessageBox(NULL,argv[2],argv[3],buttontype+icontype);
   }
   else if (argc == 4)
   {
     if (!stricmp( argv[3], "WARN"))
	 {
	   icontype = MB_ICONWARNING;
	   returnvalue = MessageBox(NULL,argv[2],"",buttontype+icontype);
	 }
     else if (!stricmp( argv[3], "INFO"))
	 { 
	   icontype = MB_ICONINFORMATION;
	   returnvalue = MessageBox(NULL,argv[2],"",buttontype+icontype);
	 } 
     else if (!stricmp( argv[3], "QUEST"))
	 {
  	   icontype = MB_ICONQUESTION;
	   returnvalue = MessageBox(NULL,argv[2],"",buttontype+icontype);
	 }  
     else if (!stricmp( argv[3], "STOP"))
	 { 
       icontype = MB_ICONSTOP;
	   returnvalue = MessageBox(NULL,argv[2],"",buttontype+icontype);
	 } 
     else  // argv[3] Must be text the the user wants printed as the caption.
	 { 
        returnvalue = MessageBox(NULL,argv[2],argv[3],buttontype);
	 } 
   }
   else
   {
	   printf("MBox: command line error, exiting.\n\n");
	   return 0;
   }
      
  // printf ("%i\n",returnvalue);
   return(returnvalue);

}

